summaryrefslogtreecommitdiff
path: root/riscos/gui/url_bar.h
diff options
context:
space:
mode:
Diffstat (limited to 'riscos/gui/url_bar.h')
-rw-r--r--riscos/gui/url_bar.h16
1 files changed, 15 insertions, 1 deletions
diff --git a/riscos/gui/url_bar.h b/riscos/gui/url_bar.h
index 0f5c6bc14..edc77640b 100644
--- a/riscos/gui/url_bar.h
+++ b/riscos/gui/url_bar.h
@@ -39,6 +39,20 @@ typedef enum {
struct url_bar;
/**
+ * Initialise the url bar module.
+ *
+ * \return True iff success, else false.
+ */
+
+bool ro_gui_url_bar_init(void);
+
+/**
+ * Finalise the url bar module
+ */
+
+void ro_gui_url_bar_fini(void);
+
+/**
* Create a new url bar widget.
*
* \param *theme The theme to apply (or NULL for the default).
@@ -120,7 +134,7 @@ bool ro_gui_url_bar_hide(struct url_bar *url_bar, bool hide);
/**
* Handle redraw event rectangles in a URL bat.
*
* \param *url_bar The URL bar to use.
* \param *redraw The Wimp redraw rectangle to process.
@@ -120,7 +134,7 @@ bool ro_gui_url_bar_hide(struct url_bar *url_bar, bool hide);
/**
- * Handle redraw event rectangles in a URL bat.
+ * Handle redraw event rectangles in a URL bar.
*
* \param *url_bar The URL bar to use.